import { useEffect, useRef } from "react";
import { ExpoSpeechRecognitionModuleEmitter } from "./ExpoSpeechRecognitionModule";
/**
 * This hook allows you to listen to native events emitted by the `ExpoSpeechRecognitionModule`.
 *
 * Note: this is not the same as the `SpeechRecognition` event listener on the web speech API.
 *
 * @param eventName The name of the event to listen to
 * @param listener The listener function to call when the event is emitted
 */
export function useSpeechRecognitionEvent(eventName, listener) {
    const listenerRef = useRef(listener);
    listenerRef.current = listener;
    useEffect(() => {
        const handler = listenerRef.current;
        const subscription = ExpoSpeechRecognitionModuleEmitter.addListener(eventName, handler);
        return subscription.remove;
    }, [eventName, listenerRef]);
}
//# sourceMappingURL=useSpeechRecognitionEvent.js.map